BASE_URL = 'http://test.connect.gosolid.io/api/v1/'

BITBUCKET_URL = 'https://%(username)s:%(password)s@bitbucket.org/gosolid/%(repository)s'
VAGRANTFILE_NAME = 'Vagrantfile'
DEFAULT_GIT_BRANCH = 'prod'